@@ -33,7 +33,7 @@
 
 #define _GNU_SOURCE // needed for wcsdup() before glibc 2.10
 
-#include "hidapi.h"
+#include "indi_hidapi.h"
 #include "locale_compat.h"
 
 /* GNU / LibUSB */
