@@ -65,7 +65,7 @@ extern "C" {
 #include <stdio.h>
 #include <stdlib.h>
 
-#include "hidapi.h"
+#include "indi_hidapi.h"
 
 #ifdef _MSC_VER
 // Thanks Microsoft, but I know how to use strncpy().
